OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Embedded message %s",
    "Important mail" : "Important mail",
    "No message found yet" : "No message found yet",
    "Set up an account" : "Set up an account",
    "Unread mail" : "Unread mail",
    "Important" : "Important",
    "Work" : "Work",
    "Personal" : "Personal",
    "To Do" : "To Do",
    "Later" : "Later",
    "Mail" : "Mail",
    "You are reaching your mailbox quota limit for {account_email}" : "You are reaching your mailbox quota limit for {account_email}",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails.",
    "Mails" : "Mails",
    "💌 A mail app for Nextcloud" : "💌 A mail app for Nextcloud",
    "Your session has expired. The page will be reloaded." : "Your session has expired. The page will be reloaded.",
    "Drafts are saved in:" : "Drafts are saved in:",
    "Sent messages are saved in:" : "Sent messages are saved in:",
    "Deleted messages are moved in:" : "Deleted messages are moved in:",
    "Archived messages are moved in:" : "Archived messages are moved in:",
    "Snoozed messages are moved in:" : "Snoozed messages are moved in:",
    "Junk messages are saved in:" : "Junk messages are saved in:",
    "Connecting" : "Connecting",
    "Reconnect Google account" : "Reconnect Google account",
    "Sign in with Google" : "Sign in with Google",
    "Save" : "Save",
    "Connect" : "Connect",
    "Looking up configuration" : "Looking up configuration",
    "Checking mail host connectivity" : "Checking mail host connectivity",
    "Configuration discovery failed. Please use the manual settings" : "Configuration discovery failed. Please use the manual settings",
    "Password required" : "Password required",
    "Testing authentication" : "Testing authentication",
    "Awaiting user consent" : "Awaiting user consent",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Account created. Please follow the pop-up instructions to link your Google account",
    "Loading account" : "Loading account",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Account updated. Please follow the pop-up instructions to reconnect your Google account",
    "Account updated" : "Account updated",
    "IMAP server is not reachable" : "IMAP server is not reachable",
    "SMTP server is not reachable" : "SMTP server is not reachable",
    "IMAP username or password is wrong" : "IMAP username or password is wrong",
    "SMTP username or password is wrong" : "SMTP username or password is wrong",
    "IMAP connection failed" : "IMAP connection failed",
    "SMTP connection failed" : "SMTP connection failed",
    "Authorization pop-up closed" : "Authorization pop-up closed",
    "Configuration discovery temporarily not available. Please try again later." : "Configuration discovery temporarily not available. Please try again later.",
    "There was an error while setting up your account" : "There was an error while setting up your account",
    "Auto" : "Auto",
    "Name" : "Name",
    "Mail address" : "Mail address",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "Please enter an email of the format name@example.com",
    "Password" : "პაროლი",
    "Manual" : "Manual",
    "IMAP Settings" : "IMAP Settings",
    "IMAP Host" : "IMAP Host",
    "IMAP Security" : "IMAP Security",
    "None" : "None",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP User",
    "IMAP Password" : "IMAP Password",
    "SMTP Settings" : "SMTP Settings",
    "SMTP Host" : "SMTP Host",
    "SMTP Security" : "SMTP Security",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP User",
    "SMTP Password" : "SMTP Password",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password.",
    "Account settings" : "Account settings",
    "Aliases" : "Aliases",
    "Alias to S/MIME certificate mapping" : "Alias to S/MIME certificate mapping",
    "Signature" : "Signature",
    "A signature is added to the text of new messages and replies." : "A signature is added to the text of new messages and replies.",
    "Writing mode" : "Writing mode",
    "Preferred writing mode for new messages and replies." : "Preferred writing mode for new messages and replies.",
    "Default folders" : "Default folders",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages.",
    "Automatic trash deletion" : "Automatic trash deletion",
    "Days after which messages in Trash will automatically be deleted:" : "Days after which messages in Trash will automatically be deleted:",
    "Autoresponder" : "Autoresponder",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days.",
    "Mail server" : "Mail server",
    "Update alias" : "Update alias",
    "Rename alias" : "Rename alias",
    "Show update alias form" : "Show update alias form",
    "Delete alias" : "Delete alias",
    "Go back" : "Go back",
    "Change name" : "Change name",
    "Email address" : "Email address",
    "Add alias" : "Add alias",
    "Create alias" : "Create alias",
    "Cancel" : "Cancel",
    "Search in the body of messages in priority Inbox" : "Search in the body of messages in priority Inbox",
    "Activate" : "Activate",
    "Put my text to the bottom of a reply instead of on top of it." : "Put my text to the bottom of a reply instead of on top of it.",
    "Could not update preference" : "Could not update preference",
    "Mail settings" : "Mail settings",
    "Accounts" : "Accounts",
    "Add mail account" : "Add mail account",
    "General" : "General",
    "List" : "List",
    "Sorting" : "Sorting",
    "Newest" : "Newest",
    "Oldest" : "Oldest",
    "Reply text position" : "Reply text position",
    "Gravatar settings" : "Gravatar settings",
    "Use Gravatar and favicon avatars" : "Use Gravatar and favicon avatars",
    "Mailto" : "Mailto",
    "Register as application for mail links" : "Register as application for mail links",
    "Register" : "Register",
    "Shared with me" : "Shared with me",
    "Data collection consent" : "Data collection consent",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
    "Trusted senders" : "Trusted senders",
    "S/MIME" : "S/MIME",
    "Manage S/MIME certificates" : "Manage S/MIME certificates",
    "Mailvelope" : "Mailvelope",
    "Looking for a way to encrypt your emails?" : "Looking for a way to encrypt your emails?",
    "About" : "About",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Compose new message" : "Compose new message",
    "Newer message" : "Newer message",
    "Older message" : "Older message",
    "Toggle star" : "Toggle star",
    "Toggle unread" : "Toggle unread",
    "Archive" : "Archive",
    "Delete" : "Delete",
    "Search" : "Search",
    "Send" : "Send",
    "Refresh" : "Refresh",
    "Ok" : "Ok",
    "No certificate" : "No certificate",
    "Certificate updated" : "Certificate updated",
    "Could not update certificate" : "Could not update certificate",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Valid until {expiryDate}",
    "Select an alias" : "Select an alias",
    "Update Certificate" : "Update Certificate",
    "Encrypt with S/MIME and send later" : "Encrypt with S/MIME and send later",
    "Encrypt with S/MIME and send" : "Encrypt with S/MIME and send",
    "Encrypt with Mailvelope and send later" : "Encrypt with Mailvelope and send later",
    "Encrypt with Mailvelope and send" : "Encrypt with Mailvelope and send",
    "Send later" : "Send later",
    "Message {id} could not be found" : "Message {id} could not be found",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Any existing formatting (for example bold, italic, underline or inline images) will be removed.",
    "Turn off formatting" : "Turn off formatting",
    "Turn off and remove formatting" : "Turn off and remove formatting",
    "Keep formatting" : "Keep formatting",
    "From" : "From",
    "Select account" : "Select account",
    "To" : "To",
    "Contact or email address …" : "Contact or email address …",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Subject",
    "Subject …" : "Subject …",
    "This message came from a noreply address so your reply will probably not be read." : "This message came from a noreply address so your reply will probably not be read.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "The following recipients do not have a S/MIME certificate: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "The following recipients do not have a PGP key: {recipients}.",
    "Write message …" : "Write message …",
    "Saving draft …" : "Saving draft …",
    "Error saving draft" : "Error saving draft",
    "Draft saved" : "Draft saved",
    "Save draft" : "Save draft",
    "Discard & close draft" : "Discard & close draft",
    "Enable formatting" : "Enable formatting",
    "Disable formatting" : "Disable formatting",
    "Upload attachment" : "Upload attachment",
    "Add attachment from Files" : "Add attachment from Files",
    "Smart picker" : "Smart picker",
    "Request a read receipt" : "Request a read receipt",
    "Sign message with S/MIME" : "Sign message with S/MIME",
    "Encrypt message with S/MIME" : "Encrypt message with S/MIME",
    "Encrypt message with Mailvelope" : "Encrypt message with Mailvelope",
    "Send now" : "Send now",
    "Tomorrow morning" : "Tomorrow morning",
    "Tomorrow afternoon" : "Tomorrow afternoon",
    "Monday morning" : "Monday morning",
    "Custom date and time" : "Custom date and time",
    "Enter a date" : "Enter a date",
    "Choose" : "Choose",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["The attachment exceed the allowed attachments size of {size}. Please share the file via link instead.","The attachments exceed the allowed attachments size of {size}. Please share the files via link instead."],
    "Choose a file to add as attachment" : "Choose a file to add as attachment",
    "Choose a file to share as a link" : "Choose a file to share as a link",
    "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} attachments"],
    "Untitled message" : "Untitled message",
    "Expand composer" : "Expand composer",
    "Close composer" : "Close composer",
    "Confirm" : "Confirm",
    "Tag: {name} deleted" : "Tag: {name} deleted",
    "An error occurred, unable to delete the tag." : "An error occurred, unable to delete the tag.",
    "The tag will be deleted from all messages." : "The tag will be deleted from all messages.",
    "Plain text" : "Plain text",
    "Rich text" : "Rich text",
    "No messages" : "No messages",
    "Blind copy recipients only" : "Blind copy recipients only",
    "No subject" : "No subject",
    "Later today – {timeLocale}" : "Later today – {timeLocale}",
    "Set reminder for later today" : "Set reminder for later today",
    "Tomorrow – {timeLocale}" : "Tomorrow – {timeLocale}",
    "Set reminder for tomorrow" : "Set reminder for tomorrow",
    "This weekend – {timeLocale}" : "This weekend – {timeLocale}",
    "Set reminder for this weekend" : "Set reminder for this weekend",
    "Next week – {timeLocale}" : "Next week – {timeLocale}",
    "Set reminder for next week" : "Set reminder for next week",
    "Could not delete message" : "Could not delete message",
    "Could not archive message" : "Could not archive message",
    "Thread was snoozed" : "Thread was snoozed",
    "Could not snooze thread" : "Could not snooze thread",
    "Thread was unsnoozed" : "Thread was unsnoozed",
    "Could not unsnooze thread" : "Could not unsnooze thread",
    "Encrypted message" : "Encrypted message",
    "This message is unread" : "This message is unread",
    "Unfavorite" : "Unfavorite",
    "Favorite" : "Favorite",
    "Unread" : "Unread",
    "Read" : "Read",
    "Unimportant" : "Unimportant",
    "Mark not spam" : "Mark not spam",
    "Mark as spam" : "Mark as spam",
    "Edit tags" : "Edit tags",
    "Snooze" : "Snooze",
    "Unsnooze" : "Unsnooze",
    "Move thread" : "Move thread",
    "Archive thread" : "Archive thread",
    "Archive message" : "Archive message",
    "Delete thread" : "Delete thread",
    "Delete message" : "Delete message",
    "More actions" : "More actions",
    "Back" : "Back",
    "Set custom snooze" : "Set custom snooze",
    "Edit as new message" : "Edit as new message",
    "Create event" : "Create event",
    "Create task" : "Create task",
    "Download message" : "Download message",
    "Load more" : "Load more",
    "_Mark {number} read_::_Mark {number} read_" : ["Mark {number} read","Mark {number} read"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Mark {number} unread","Mark {number} unread"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Mark {number} as important","Mark {number} as important"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Mark {number} as unimportant","Mark {number} as unimportant"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Unfavorite {number}","Unfavorite {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["Favorite {number}","Favorite {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["Unselect {number}","Unselect {number}"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Mark {number} as spam","Mark {number} as spam"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["Mark {number} as not spam","Mark {number} as not spam"],
    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Edit tags for {number}","Edit tags for {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["Move {number} thread","Move {number} threads"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Forward {number} as attachment","Forward {number} as attachment"],
    "Report this bug" : "Report this bug",
    "Event created" : "Event created",
    "Could not create event" : "Could not create event",
    "All day" : "All day",
    "Select calendar" : "Select calendar",
    "Description" : "Description",
    "Create" : "Create",
    "This event was updated" : "This event was updated",
    "{attendeeName} accepted your invitation" : "{attendeeName} accepted your invitation",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} tentatively accepted your invitation",
    "{attendeeName} declined your invitation" : "{attendeeName} declined your invitation",
    "{attendeeName} reacted to your invitation" : "{attendeeName} reacted to your invitation",
    "Failed to save your participation status" : "Failed to save your participation status",
    "You accepted this invitation" : "You accepted this invitation",
    "You tentatively accepted this invitation" : "You tentatively accepted this invitation",
    "You declined this invitation" : "You declined this invitation",
    "You already reacted to this invitation" : "You already reacted to this invitation",
    "You have been invited to an event" : "You have been invited to an event",
    "This event was cancelled" : "This event was cancelled",
    "Save to" : "Save to",
    "Select" : "Select",
    "Comment" : "Comment",
    "Accept" : "Accept",
    "Decline" : "Decline",
    "Tentatively accept" : "Tentatively accept",
    "More options" : "More options",
    "individual" : "individual",
    "domain" : "domain",
    "Remove" : "Remove",
    "email" : "email",
    "Itinerary for {type} is not supported yet" : "Itinerary for {type} is not supported yet",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "You are not allowed to move this message to the archive folder and/or delete this message from the current folder",
    "Today" : "დღეს",
    "Yesterday" : "გუშინ",
    "Last week" : "Last week",
    "Last month" : "Last month",
    "Loading messages …" : "Loading messages …",
    "Choose target folder" : "Choose target folder",
    "No more submailboxes in here" : "No more submailboxes in here",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time.",
    "Important info" : "Important info",
    "Other" : "Other",
    "Could not send mdn" : "Could not send mdn",
    "The sender of this message has asked to be notified when you read this message." : "The sender of this message has asked to be notified when you read this message.",
    "Notify the sender" : "Notify the sender",
    "You sent a read confirmation to the sender of this message." : "You sent a read confirmation to the sender of this message.",
    "Message was snoozed" : "Message was snoozed",
    "Could not snooze message" : "Could not snooze message",
    "Message was unsnoozed" : "Message was unsnoozed",
    "Could not unsnooze message" : "Could not unsnooze message",
    "Forward" : "Forward",
    "Move message" : "Move message",
    "Translate" : "Translate",
    "Forward message as attachment" : "Forward message as attachment",
    "View source" : "View source",
    "Download thread data for debugging" : "Download thread data for debugging",
    "Message body" : "Message body",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!",
    "Unnamed" : "Unnamed",
    "Embedded message" : "Embedded message",
    "calendar imported" : "calendar imported",
    "Choose a folder to store the attachment in" : "Choose a folder to store the attachment in",
    "Import into calendar" : "Import into calendar",
    "Download attachment" : "Download attachment",
    "Save to Files" : "Save to Files",
    "View fewer attachments" : "View fewer attachments",
    "Choose a folder to store the attachments in" : "Choose a folder to store the attachments in",
    "Save all to Files" : "Save all to Files",
    "Download Zip" : "Download Zip",
    "_View {count} more attachment_::_View {count} more attachments_" : ["View {count} more attachment","View {count} more attachments"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "This message is encrypted with PGP. Install Mailvelope to decrypt it.",
    "The images have been blocked to protect your privacy." : "The images have been blocked to protect your privacy.",
    "Show images" : "Show images",
    "Show images temporarily" : "Show images temporarily",
    "Always show images from {sender}" : "Always show images from {sender}",
    "Always show images from {domain}" : "Always show images from {domain}",
    "Message frame" : "Message frame",
    "Quoted text" : "Quoted text",
    "Move" : "Move",
    "Moving" : "Moving",
    "Moving thread" : "Moving thread",
    "Moving message" : "Moving message",
    "Remove account" : "Remove account",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider.",
    "Remove {email}" : "Remove {email}",
    "Provisioned account is disabled" : "Provisioned account is disabled",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn.",
    "Folder name" : "Folder name",
    "Saving" : "Saving",
    "Move up" : "Move up",
    "Move down" : "Move down",
    "_{total} message_::_{total} messages_" : ["{total} message","{total} messages"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} unread of {total}","{unread} unread of {total}"],
    "Loading …" : "Loading …",
    "All messages in mailbox will be deleted." : "All messages in mailbox will be deleted.",
    "Clear mailbox {name}" : "Clear mailbox {name}",
    "Delete folder" : "Delete folder",
    "An error occurred, unable to rename the mailbox." : "An error occurred, unable to rename the mailbox.",
    "Mark all as read" : "Mark all as read",
    "Rename" : "Rename",
    "Clear cache" : "Clear cache",
    "Clear locally cached data, in case there are issues with synchronization." : "Clear locally cached data, in case there are issues with synchronization.",
    "Subscribed" : "Subscribed",
    "Sync in background" : "Sync in background",
    "Outbox" : "Outbox",
    "New message" : "New message",
    "Edit message" : "Edit message",
    "Draft" : "Draft",
    "Reply" : "Reply",
    "Message saved" : "Message saved",
    "Failed to save message" : "Failed to save message",
    "Failed to save draft" : "Failed to save draft",
    "attachment" : "attachment",
    "attached" : "attached",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses.",
    "You mentioned an attachment. Did you forget to add it?" : "You mentioned an attachment. Did you forget to add it?",
    "Message discarded" : "Message discarded",
    "Could not discard message" : "Could not discard message",
    "Minimize composer" : "Minimize composer",
    "Error sending your message" : "Error sending your message",
    "Retry" : "Retry",
    "Warning sending your message" : "Warning sending your message",
    "Send anyway" : "Send anyway",
    "Autoresponder off" : "Autoresponder off",
    "Autoresponder on" : "Autoresponder on",
    "Autoresponder follows system settings" : "Autoresponder follows system settings",
    "The autoresponder follows your personal absence period settings." : "The autoresponder follows your personal absence period settings.",
    "Edit absence settings" : "Edit absence settings",
    "First day" : "First day",
    "Last day (optional)" : "Last day (optional)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} will be replaced with the subject of the message you are responding to",
    "Message" : "Message",
    "Oh Snap!" : "Oh Snap!",
    "Save autoresponder" : "Save autoresponder",
    "Could not open outbox" : "Could not open outbox",
    "Pending or not sent messages will show up here" : "Pending or not sent messages will show up here",
    "Message could not be sent" : "Message could not be sent",
    "Message deleted" : "Message deleted",
    "Copied email address to clipboard" : "Copied email address to clipboard",
    "Could not copy email address to clipboard" : "Could not copy email address to clipboard",
    "Contacts with this address" : "Contacts with this address",
    "Add to Contact" : "Add to Contact",
    "New Contact" : "New Contact",
    "Copy to clipboard" : "Copy to clipboard",
    "Contact name …" : "Contact name …",
    "Add" : "Add",
    "Show less" : "Show less",
    "Show more" : "Show more",
    "Clear" : "Clear",
    "Close" : "Close",
    "Search parameters" : "Search parameters",
    "Search subject" : "Search subject",
    "Body" : "Body",
    "Search body" : "Search body",
    "Date" : "Date",
    "Pick a start date" : "Pick a start date",
    "Pick an end date" : "Pick an end date",
    "Select senders" : "Select senders",
    "Select recipients" : "Select recipients",
    "Select CC recipients" : "Select CC recipients",
    "Select BCC recipients" : "Select BCC recipients",
    "Tags" : "Tags",
    "Select tags" : "Select tags",
    "Marked as" : "Marked as",
    "Has attachments" : "Has attachments",
    "Last 7 days" : "Last 7 days",
    "Enable mail body search" : "Enable mail body search",
    "Sieve Port" : "Sieve Port",
    "Custom" : "Custom",
    "Sieve User" : "Sieve User",
    "Sieve Password" : "Sieve Password",
    "Save sieve settings" : "Save sieve settings",
    "The syntax seems to be incorrect:" : "The syntax seems to be incorrect:",
    "Save sieve script" : "Save sieve script",
    "Signature …" : "Signature …",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Your signature is larger than 2 MB. This may affect the performance of your editor.",
    "Save signature" : "Save signature",
    "Place signature above quoted text" : "Place signature above quoted text",
    "Message source" : "Message source",
    "An error occurred, unable to rename the tag." : "An error occurred, unable to rename the tag.",
    "Edit name or color" : "Edit name or color",
    "Saving new tag name …" : "Saving new tag name …",
    "Delete tag" : "Delete tag",
    "Set tag" : "Set tag",
    "Unset tag" : "Unset tag",
    "Tag name is a hidden system tag" : "Tag name is a hidden system tag",
    "Tag already exists" : "Tag already exists",
    "Tag name cannot be empty" : "Tag name cannot be empty",
    "An error occurred, unable to create the tag." : "An error occurred, unable to create the tag.",
    "Add default tags" : "Add default tags",
    "Add tag" : "Add tag",
    "Saving tag …" : "Saving tag …",
    "Task created" : "Task created",
    "Could not create task" : "Could not create task",
    "No calendars with task list support" : "No calendars with task list support",
    "Summarizing thread failed." : "Summarizing thread failed.",
    "Could not load your message thread" : "Could not load your message thread",
    "The thread doesn't exist or has been deleted" : "The thread doesn't exist or has been deleted",
    "Loading thread" : "Loading thread",
    "Not found" : "Not found",
    "Encrypted & verified " : "Encrypted & verified ",
    "Signature verified" : "Signature verified",
    "Signature unverified " : "Signature unverified ",
    "This message was encrypted by the sender before it was sent." : "This message was encrypted by the sender before it was sent.",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted.",
    "Reply all" : "Reply all",
    "Unsubscribe request sent" : "Unsubscribe request sent",
    "Could not unsubscribe from mailing list" : "Could not unsubscribe from mailing list",
    "Unsubscribe" : "Unsubscribe",
    "Reply to sender only" : "Reply to sender only",
    "Mark as unfavorite" : "Mark as unfavorite",
    "Mark as favorite" : "Mark as favorite",
    "Mark as unread" : "Mark as unread",
    "Mark as read" : "Mark as read",
    "Unsubscribe via link" : "Unsubscribe via link",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "Unsubscribing will stop all messages from the mailing list {sender}",
    "Send unsubscribe email" : "Send unsubscribe email",
    "Unsubscribe via email" : "Unsubscribe via email",
    "{name} Assistant" : "{name} Assistant",
    "Go to latest message" : "Go to latest message",
    "Go to newest message" : "Go to newest message",
    "The message could not be translated" : "The message could not be translated",
    "Translation copied to clipboard" : "Translation copied to clipboard",
    "Translation could not be copied" : "Translation could not be copied",
    "Translate message" : "Translate message",
    "Source language to translate from" : "Source language to translate from",
    "Translate from" : "Translate from",
    "Target language to translate into" : "Target language to translate into",
    "Translate to" : "Translate to",
    "Translating" : "Translating",
    "Copy translated text" : "Copy translated text",
    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed.",
    "Could not remove trusted sender {sender}" : "Could not remove trusted sender {sender}",
    "No senders are trusted at the moment." : "No senders are trusted at the moment.",
    "Untitled event" : "Untitled event",
    "(organizer)" : "(organizer)",
    "Import into {calendar}" : "Import into {calendar}",
    "Event imported into {calendar}" : "Event imported into {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flight {flightNr} from {depAirport} to {arrAirport}",
    "Airplane" : "Airplane",
    "Reservation {id}" : "Reservation {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} from {depStation} to {arrStation}",
    "Train from {depStation} to {arrStation}" : "Train from {depStation} to {arrStation}",
    "Train" : "Train",
    "Operator" : "ოპერატორი",
    "matches" : "matches",
    "Priority" : "Priority",
    "Successfully updated config for \"{domain}\"" : "Successfully updated config for \"{domain}\"",
    "Error saving config" : "Error saving config",
    "Saved config for \"{domain}\"" : "Saved config for \"{domain}\"",
    "Could not save provisioning setting" : "Could not save provisioning setting",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Successfully provisioned {count} account.","Successfully provisioned {count} accounts."],
    "There was an error when provisioning accounts." : "There was an error when provisioning accounts.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Successfully deleted and deprovisioned accounts for \"{domain}\"",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Error when deleting and deprovisioning accounts for \"{domain}\"",
    "Mail app" : "Mail app",
    "The mail app allows users to read mails on their IMAP accounts." : "The mail app allows users to read mails on their IMAP accounts.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner).",
    "Account provisioning" : "Account provisioning",
    "A provisioning configuration will provision all accounts with a matching email address." : "A provisioning configuration will provision all accounts with a matching email address.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "There can only be one configuration per domain and only one wildcard domain configuration.",
    "These settings can be used in conjunction with each other." : "These settings can be used in conjunction with each other.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "If you only want to provision one domain for all users, use the wildcard (*).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization.",
    "Provisioning Configurations" : "Provisioning Configurations",
    "Add new config" : "Add new config",
    "Provision all accounts" : "Provision all accounts",
    "Allow additional mail accounts" : "Allow additional mail accounts",
    "Allow additional Mail accounts from User Settings" : "Allow additional Mail accounts from User Settings",
    "Anti Spam Service" : "Anti Spam Service",
    "You can set up an anti spam service email address here." : "You can set up an anti spam service email address here.",
    "Any email that is marked as spam will be sent to the anti spam service." : "Any email that is marked as spam will be sent to the anti spam service.",
    "Gmail integration" : "Gmail integration",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords.",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI.",
    "Microsoft integration" : "Microsoft integration",
    "Successfully set up anti spam email addresses" : "Successfully set up anti spam email addresses",
    "Error saving anti spam email addresses" : "Error saving anti spam email addresses",
    "Successfully deleted anti spam reporting email" : "Successfully deleted anti spam reporting email",
    "Error deleting anti spam reporting email" : "Error deleting anti spam reporting email",
    "Anti Spam" : "Anti Spam",
    "Add the email address of your anti spam report service here." : "Add the email address of your anti spam report service here.",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\".",
    "The original message will be attached as a \"message/rfc822\" attachment." : "The original message will be attached as a \"message/rfc822\" attachment.",
    "\"Mark as Spam\" Email Address" : "\"Mark as Spam\" Email Address",
    "\"Mark Not Junk\" Email Address" : "\"Mark Not Junk\" Email Address",
    "Reset" : "Reset",
    "Google integration configured" : "Google integration configured",
    "Could not configure Google integration" : "Could not configure Google integration",
    "Google integration unlinked" : "Google integration unlinked",
    "Could not unlink Google integration" : "Could not unlink Google integration",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "Unlink" : "Unlink",
    "Microsoft integration configured" : "Microsoft integration configured",
    "Could not configure Microsoft integration" : "Could not configure Microsoft integration",
    "Microsoft integration unlinked" : "Microsoft integration unlinked",
    "Could not unlink Microsoft integration" : "Could not unlink Microsoft integration",
    "Tenant ID (optional)" : "Tenant ID (optional)",
    "Domain Match: {provisioningDomain}" : "Domain Match: {provisioningDomain}",
    "Email: {email}" : "Email: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} on {host}:{port} ({ssl} encryption)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} on {host}:{port} ({ssl} encryption)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} on {host}:{port} ({ssl} encryption)",
    "Configuration for \"{provisioningDomain}\"" : "Configuration for \"{provisioningDomain}\"",
    "Provisioning domain" : "Provisioning domain",
    "Email address template" : "Email address template",
    "IMAP" : "IMAP",
    "User" : "User",
    "Host" : "Host",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Master password" : "Master password",
    "Use master password" : "Use master password",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Enable sieve integration",
    "LDAP aliases integration" : "LDAP aliases integration",
    "Enable LDAP aliases integration" : "Enable LDAP aliases integration",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases.",
    "LDAP attribute for aliases" : "LDAP attribute for aliases",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted.",
    "Save Config" : "Save Config",
    "Unprovision & Delete Config" : "Unprovision & Delete Config",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% and %EMAIL% will be replaced with the user's UID and email",
    "With the settings above, the app will create account settings in the following way:" : "With the settings above, the app will create account settings in the following way:",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key.",
    "Failed to import the certificate. Please check the password." : "Failed to import the certificate. Please check the password.",
    "Certificate imported successfully" : "Certificate imported successfully",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase.",
    "Failed to import the certificate" : "Failed to import the certificate",
    "S/MIME certificates" : "S/MIME certificates",
    "Certificate name" : "Certificate name",
    "E-mail address" : "E-mail address",
    "Valid until" : "Valid until",
    "Delete certificate" : "Delete certificate",
    "No certificate imported yet" : "No certificate imported yet",
    "Import certificate" : "Import certificate",
    "Import S/MIME certificate" : "Import S/MIME certificate",
    "PKCS #12 Certificate" : "PKCS #12 Certificate",
    "PEM Certificate" : "PEM Certificate",
    "Certificate" : "Certificate",
    "Private key (optional)" : "Private key (optional)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "The private key is only required if you intend to send signed and encrypted emails using this certificate.",
    "Submit" : "Submit",
    "Guest" : "Guest",
    "Group" : "Group",
    "Shared" : "Shared",
    "Shares" : "Shares",
    "Account connected" : "Account connected",
    "You can close this window" : "You can close this window",
    "Connect your mail account" : "Connect your mail account",
    "To add a mail account, please contact your administrator." : "To add a mail account, please contact your administrator.",
    "All" : "All",
    "Drafts" : "Drafts",
    "Favorites" : "Favorites",
    "Priority inbox" : "Priority inbox",
    "All inboxes" : "All inboxes",
    "Inbox" : "Inbox",
    "Junk" : "Junk",
    "Sent" : "Sent",
    "Trash" : "Trash",
    "Connect OAUTH2 account" : "Connect OAUTH2 account",
    "Error while sharing file" : "Error while sharing file",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n new message \nfrom {from}","%n new messages \nfrom {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "There is already a message in progress. All unsaved changes will be lost if you continue!",
    "Discard changes" : "Discard changes",
    "Discard unsaved changes" : "Discard unsaved changes",
    "Keep editing message" : "Keep editing message",
    "Attachments were not copied. Please add them manually." : "Attachments were not copied. Please add them manually.",
    "Could not create snooze mailbox" : "Could not create snooze mailbox",
    "Message sent" : "Message sent",
    "Could not send message" : "Could not send message",
    "Could not load {tag}{name}{endtag}" : "Could not load {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "There was a problem loading {tag}{name}{endtag}",
    "Could not load your message" : "Could not load your message",
    "Could not load the desired message" : "Could not load the desired message",
    "Could not load the message" : "Could not load the message",
    "Error loading message" : "Error loading message",
    "Forwarding to %s" : "Forwarding to %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Click here if you are not automatically redirected within the next few seconds.",
    "Redirect" : "Redirect",
    "The link leads to %s" : "The link leads to %s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "Continue to %s",
    "Mailbox search" : "Mailbox search",
    "Install Mailvelope browser extension by clicking here" : "Install Mailvelope browser extension by clicking here",
    "No messages in this mailbox" : "No messages in this mailbox",
    "No trash mailbox configured" : "No trash mailbox configured",
    "Draft: " : "Draft: ",
    "To archive a message please configure an archive mailbox in account settings" : "To archive a message please configure an archive mailbox in account settings",
    "Could not open mailbox" : "Could not open mailbox",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexing your messages. This can take a bit longer for larger mailboxes.",
    "Choose target mailbox" : "Choose target mailbox",
    "Show only subscribed mailboxes" : "Show only subscribed mailboxes",
    "Add mailbox" : "Add mailbox",
    "Mailbox name" : "Mailbox name",
    "Show all subscribed mailboxes" : "Show all subscribed mailboxes",
    "Show all mailboxes" : "Show all mailboxes",
    "Collapse mailboxes" : "Collapse mailboxes",
    "Clear mailbox" : "Clear mailbox",
    "The mailbox and all messages in it will be deleted." : "The mailbox and all messages in it will be deleted.",
    "Delete mailbox" : "Delete mailbox",
    "Delete mailbox {name}" : "Delete mailbox {name}",
    "Mark all messages of this mailbox as read" : "Mark all messages of this mailbox as read",
    "Add submailbox" : "Add submailbox",
    "Move mailbox" : "Move mailbox",
    "No sent mailbox configured. Please pick one in the account settings." : "No sent mailbox configured. Please pick one in the account settings.",
    "Search in mailbox" : "Search in mailbox",
    "Actions" : "Actions"
},
"nplurals=2; plural=(n!=1);");
